﻿using IronWebScraper;
using IronWebScraperSample.Common;
using IronWebScraperSample.ShoppingSiteSample.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IronWebScraperSample.ShoppingSiteSample
{
    /// <summary>
    /// Shopping Scraper
    /// </summary>
    /// <seealso cref="WebScraper" />
    public class ShoppingScraper : WebScraper
    {
        /// <summary>
        /// Override this method initialize your web-scraper.
        /// Important tasks will be to Request at least one start url... and set allowed/banned domain or url patterns.
        /// </summary>
        public override void Init()
        {
            License.LicenseKey = "IRONWEBSCRAPER-143290-839020-5117AB04-6F50881A-F3BC5BD8-VALID-2017";
            this.LoggingLevel = WebScraper.LogLevel.All;
            this.WorkingDirectory = AppSetting.GetAppRoot() + @"\ShoppingSiteSample\Output\";
            EnableWebCache(new TimeSpan(1,30,30));
            this.Request("https://www.jumia.com.eg", Parse);
        }

        /// <summary>
        /// Override this method to create the default Response handler for your web scraper.
        /// If you have multiple page types, you can add additional similar methods.
        /// </summary>
        /// <param name="response">The http Response object to parse</param>
        public override void Parse(Response response)
        {
            // List of Categories Links (Root)
            var categoryList = new List<Category>();

            foreach (var li in response.Css("#menuFixed > ul > li"))
            {
                // List Of Main Links
                foreach (var Links in li.Css("a"))
                {
                    var cat = new Category();
                    cat.URL = Links.Attributes["href"];
                    cat.Name = Links.InnerText;
                    cat.SubCategories = new List<Category>();
                    // List of Sub Catgories Links
                    foreach (var subCategory in li.Css("a[class=subcategory]"))
                    {
                        var subcat = new Category();
                        subcat.URL = Links.Attributes["href"];
                        subcat.Name = Links.InnerText;
                        // Check If Link Exist Before 
                        if (cat.SubCategories.Find(c => c.Name == subcat.Name && c.URL == subcat.URL) == null)
                        {
                            // Add Sublinks
                            cat.SubCategories.Add(subcat);
                            this.Request(subcat.URL, ParseCatgory);// to scrap Category Page 
                        }
                    }
                    // Add Categories
                    categoryList.Add(cat);
                   
                }
            }          

        }

        public void ParseCatgory(Response response)
        {                       
            // List of Products Links (Root)
            var productList = new List<Product>();

            foreach (var Links in response.Css("body > main > section.osh-content > section.products > div > a"))
            {
                var product = new Product();
                product.Name = Links.InnerText;
                product.Image = Links.Css("div.image-wrapper.default-state > img")[0].Attributes["src"];                
                productList.Add(product);
            }

            Scrape(productList, "Products.Jsonl");
        }
    }
}
